@@ -1,4 +1,4 @@
-"""The public api functions.
+"""The public functions.
 
 These three public functions all perform the same function of dispatching a JSON-RPC
 request, but they each give a different return value.
@@ -111,5 +111,5 @@ def dispatch_to_json(
     return "" if response is None else serializer(response)
 
 
-# "dispatch" is an alias of dispatch_to_json.
+# "dispatch" aliases dispatch_to_json.
 dispatch = dispatch_to_json
